@@ -35,10 +35,10 @@ class AdvancedSearchDialog : public QDialog
 public:
     explicit AdvancedSearchDialog(
             const QString& defaultName,
-            const PlaylistSearch& defaultSearch = PlaylistSearch(),
+            PlaylistSearch& defaultSearch,
             QWidget* parent = nullptr);
 
-    PlaylistSearch resultSearch() const
+    PlaylistSearch* resultSearch() const
     {
         return m_search;
     }
@@ -58,7 +58,7 @@ private:
     void updateButtons();
 
     QBoxLayout *m_criteriaLayout;
-    PlaylistSearch m_search;
+    PlaylistSearch* m_search;
     QString m_playlistName;
     QList<SearchLine *> m_searchLines;
     QLineEdit *m_playlistNameLineEdit;
