@@ -28,7 +28,6 @@
 
 class QCheckBox;
 class QPushButton;
-class QSignalMapper;
 class QUrl;
 
 class ExampleOptionsDialog;
@@ -44,7 +43,7 @@ enum MovementDirection { MoveUp, MoveDown };
  * tag type, including its position, the QFrame holding the information,
  * the up, down, and enable buttons, and the user-selected renaming options.
  */
-struct Row
+struct Row final
 {
     Row() : widget(0), upButton(0), downButton(0), enableButton(0) {}
 
@@ -67,14 +66,6 @@ struct Row
  */
 typedef QVector<Row> Rows;
 
-/**
- * Holds a list directory separator checkboxes which separate a row.  There
- * should always be 1 less than the number of rows in the GUI.
- *
- * Used for ConfigCategoryReader.
- */
-typedef QVector<QCheckBox *> DirSeparatorCheckBoxes;
-
 /**
  * Associates a CategoryID combination with a set of options.
  *
@@ -90,7 +81,7 @@ typedef QMap<CategoryID, TagRenamerOptions> CategoryOptionsMap;
  *
  * @author Michael Pyne <mpyne@kde.org>
  */
-class ConfigCategoryReader : public CategoryReaderInterface
+class ConfigCategoryReader final : public CategoryReaderInterface
 {
 public:
     // ConfigCategoryReader specific members
@@ -137,7 +128,7 @@ private:
  *
  * @author Michael Pyne <mpyne@kde.org>
  */
-class FileRenamerWidget : public QWidget, public CategoryReaderInterface
+class FileRenamerWidget final : public QWidget, public CategoryReaderInterface
 {
     Q_OBJECT
 
@@ -213,14 +204,10 @@ private:
     bool removeRow(int id);
 
     /**
-     * Updates the mappings currently set for the row identified by oldId so
-     * that they emit newId instead.  Does not actually delete the row given
-     * by oldId.
-     *
-     * @param oldId The identifier of the row to change mappings for.
-     * @param newId The identifier to use instead.
+     * Installs button signal handlers for the buttons in @p row so that they
+     * are called in response to GUI events, and removes any existing handlers.
      */
-    void moveSignalMappings(int oldId, int newId);
+    void assignPositionHandlerForRow(Row &row);
 
     /**
      * This function sets up the internal view by creating the checkboxes and
@@ -367,16 +354,6 @@ private:
      */
     void setCategoryEnabled(int id, bool enable);
 
-    /**
-     * This function enables all of the up buttons.
-     */
-    void enableAllUpButtons();
-
-    /**
-     * This function enables all of the down buttons.
-     */
-    void enableAllDownButtons();
-
     /**
      * This function returns the identifier of the row at \p position.
      *
@@ -423,7 +400,6 @@ private slots:
     /**
      * This function removes the row identified by id and updates the internal data to be
      * consistent again, by forwarding the call to removeRow().
-     * This roundabout way is done due to QSignalMapper.
      *
      * @param id The unique id to update
      */
@@ -475,19 +451,13 @@ private:
      * This holds an array of checkboxes that allow the user to insert folder
      * separators in between categories.
      */
-    DirSeparatorCheckBoxes m_folderSwitches;
+    QVector<QCheckBox *> m_folderSwitches;
 
     ExampleOptionsDialog *m_exampleDialog;
 
     /// This is true if we're reading example tags from m_exampleFile.
     bool m_exampleFromFile;
     QString m_exampleFile;
-
-    // Used to map signals from rows to the correct widget.
-    QSignalMapper *mapper;
-    QSignalMapper *toggleMapper;
-    QSignalMapper *upMapper;
-    QSignalMapper *downMapper;
 };
 
 /**
@@ -498,7 +468,7 @@ private:
  *
  * @author Michael Pyne <mpyne@kde.org>
  */
-class FileRenamer
+class FileRenamer final
 {
 public:
     FileRenamer();
