@@ -31,31 +31,28 @@
 #include <kactionmenu.h>
 #include <ktoggleaction.h>
 
+#include <QActionGroup>
+#include <QClipboard>
 #include <QCursor>
 #include <QDesktopServices>
 #include <QDir>
-#include <QDirIterator>
-#include <QHash>
-#include <QToolTip>
+#include <QDragEnterEvent>
+#include <QDropEvent>
 #include <QFile>
 #include <QFileDialog>
 #include <QHeaderView>
-#include <QList>
-#include <QResizeEvent>
-#include <QMouseEvent>
 #include <QKeyEvent>
-#include <QMimeData>
+#include <QList>
 #include <QMenu>
-#include <QTimer>
-#include <QClipboard>
-#include <QTextStream>
-#include <QDropEvent>
-#include <QDragEnterEvent>
-#include <QPixmap>
+#include <QMimeData>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QResizeEvent>
+#include <QScrollBar>
 #include <QSet>
 #include <QStackedWidget>
-#include <QScrollBar>
-#include <QPainter>
+#include <QTextStream>
+#include <QTimer>
 
 #include <QtConcurrent>
 #include <QFutureWatcher>
@@ -1916,11 +1913,7 @@ void Playlist::slotUpdateColumnWidths()
 
     // convenience handler for deprecated text metrics
     const auto textWidth = [](const QFontMetrics &fm, const QString &text) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
         return fm.horizontalAdvance(text);
-#else
-        return fm.width(text);
-#endif
     };
 
     // No item content to auto-fit around, use the headers for now
