@@ -47,7 +47,6 @@ public:
 
 public slots:
     void clear();
-    virtual void setFocus();
 
 protected:
     virtual bool eventFilter(QObject *watched, QEvent *e) override;
@@ -76,6 +75,7 @@ public:
     explicit SearchWidget(QWidget *parent);
 
     PlaylistSearch* search(const PlaylistList& playlists) const;
+    PlaylistSearch* search(Playlist *playlist) const;
     void setSearch(const PlaylistSearch* search);
 
     virtual QString searchText() const;
