@@ -28,17 +28,15 @@
 #include "juk.h"
 #include "juk_debug.h"
 
-#include <QPixmap>
-#include <QIcon>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QDomDocument>
 #include <QDomElement>
+#include <QLabel>
+#include <QLayout>
+#include <QPixmap>
 #include <QPointer>
 #include <QPushButton>
-#include <QLayout>
-#include <QLabel>
-#include <QPainter>
 #include <QStatusBar>
 #include <QUrl>
 #include <QUrlQuery>
@@ -189,7 +187,7 @@ void WebImageFetcher::slotImageFetched(KJob* j)
     if(job->error()) {
         qCCritical(JUK_LOG) << "Unable to grab image" << job->errorText();
 
-        KMessageBox::sorry(nullptr, i18n("Failed to download requested cover art: %1", job->errorString()),
+        KMessageBox::error(nullptr, i18n("Failed to download requested cover art: %1", job->errorString()),
                 i18nc("@title:window", "Could not download cover art"));
         return;
     }
